==> gst-plugins-0.7.1.tar.gz: gst-plugins-0.7.1/gst/filter/gstfilter.c <==
/* GStreamer
 * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
 *                    2000 Wim Taymans <wtay@chello.be>
 *
 * gstfilter.c: element for filter plug-ins
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "gstfilter.h"
#include <gst/audio/audio.h>


struct _elements_entry {
  gchar *name;
  GType (*type) (void);
  GstElementDetails *details;
  gboolean (*factoryinit) (GstElementFactory *factory);
};

static struct _elements_entry _elements[] = {
  { "iir",  	gst_iir_get_type,  	&gst_iir_details,  	NULL },
  { "lpwsinc",  gst_lpwsinc_get_type,	&gst_lpwsinc_details,	NULL },
  { "bpwsinc",  gst_bpwsinc_get_type,	&gst_bpwsinc_details,	NULL },
  { NULL, 0 },
};

GstPadTemplate*
gst_filter_src_factory (void)
{
  static GstPadTemplate *templ = NULL;
  if (!templ) {
    templ = GST_PAD_TEMPLATE_NEW (
  		"src",
  		GST_PAD_SRC,
  		GST_PAD_ALWAYS,
  		gst_caps_new (
  		  "filter_src",
  		  "audio/x-raw-float",
  	          GST_AUDIO_FLOAT_STANDARD_PAD_TEMPLATE_PROPS
		)
  	     );
  }
  return templ;
}

GstPadTemplate*
gst_filter_sink_factory (void)
{
  static GstPadTemplate *templ = NULL;
  if (!templ) {
    templ = GST_PAD_TEMPLATE_NEW (
  		"sink",
  		GST_PAD_SINK,
  		GST_PAD_ALWAYS,
  		gst_caps_new (
  		  "filter_src",
  		  "audio/x-raw-float",
  		  GST_AUDIO_FLOAT_STANDARD_PAD_TEMPLATE_PROPS
		)
  	     );
  }
  return templ;
}

static gboolean
plugin_init (GModule * module, GstPlugin * plugin)
{
  GstElementFactory *factory;
  gint i = 0;

  while (_elements[i].name) {
    factory = gst_element_factory_new (_elements[i].name,
                                      (_elements[i].type) (),
                                       _elements[i].details);

    if (!factory) {
      g_warning ("gst_filter_new failed for `%s'",
                 _elements[i].name);
      continue;
    }
    gst_element_factory_add_pad_template (factory, gst_filter_src_factory ());
    gst_element_factory_add_pad_template (factory, gst_filter_sink_factory ());

    gst_plugin_add_feature (plugin, GST_PLUGIN_FEATURE (factory));
    if (_elements[i].factoryinit) {
      _elements[i].factoryinit (factory);
    }
    i++;
  }

  return TRUE;
}

GstPluginDesc plugin_desc = {
  GST_VERSION_MAJOR,
  GST_VERSION_MINOR,
  "filter",
  plugin_init
};

==> gst-plugins-0.7.3.tar.gz: gst-plugins-0.7.3/gst/filter/gstfilter.c <==
/* GStreamer
 * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
 *                    2000 Wim Taymans <wtay@chello.be>
 *
 * gstfilter.c: element for filter plug-ins
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include "gstfilter.h"
#include <gst/audio/audio.h>


struct _elements_entry {
  gchar *name;
  GType (*type) (void);
};

static struct _elements_entry _elements[] = {
  { "iir",  	gst_iir_get_type	},
  { "lpwsinc",  gst_lpwsinc_get_type	},
  { "bpwsinc",  gst_bpwsinc_get_type	},
  { NULL, 0 },
};

GstPadTemplate*
gst_filter_src_factory (void)
{
  static GstPadTemplate *templ = NULL;
  if (!templ) {
    templ = GST_PAD_TEMPLATE_NEW (
  		"src",
  		GST_PAD_SRC,
  		GST_PAD_ALWAYS,
  		gst_caps_new (
  		  "filter_src",
  		  "audio/x-raw-float",
  	          GST_AUDIO_FLOAT_STANDARD_PAD_TEMPLATE_PROPS
		)
  	     );
  }
  return templ;
}

GstPadTemplate*
gst_filter_sink_factory (void)
{
  static GstPadTemplate *templ = NULL;
  if (!templ) {
    templ = GST_PAD_TEMPLATE_NEW (
  		"sink",
  		GST_PAD_SINK,
  		GST_PAD_ALWAYS,
  		gst_caps_new (
  		  "filter_src",
  		  "audio/x-raw-float",
  		  GST_AUDIO_FLOAT_STANDARD_PAD_TEMPLATE_PROPS
		)
  	     );
  }
  return templ;
}

static gboolean
plugin_init (GstPlugin * plugin)
{
  gint i = 0;

  while (_elements[i].name) {
    if (!gst_element_register (plugin, _elements[i].name, GST_RANK_NONE, _elements[i].type()))
      return FALSE;

    i++;
  }

  return TRUE;
}

GST_PLUGIN_DEFINE (
  GST_VERSION_MAJOR,
  GST_VERSION_MINOR,
  "filter",
  "IIR, lpwsinc and bpwsinc audio filter elements",
  plugin_init,
  VERSION,
  "LGPL",
  GST_PACKAGE,
  GST_ORIGIN
);
